import { Component, EventEmitter, Input, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { User } from '../../../models/user.model';
import { Filter } from '../../../structure-list/models/filter.model';
import { OrientationUtils } from '../../../utils/orientationUtils';
import { HotlineMediationSteps } from '../enums/hotlineMediationSteps.enum';
import { OnlineDemarche } from '../enums/onlineDemarche.enum';
import { OnlineDemarchesCommonSteps } from '../enums/onlineDemarchesCommonSteps.enum';
import { OnlineDemarchesMeetingSteps } from '../enums/onlineDemarchesMeetingSteps.enum';
import { RecapsType } from '../enums/recapsType.enum';
import { StructuresListSteps } from '../enums/structuresListSteps.enum';
import { OnlineMediationSteps } from '../types/onlineDemarcheStep.type';

@Component({
  selector: 'app-onlineDemarch-form',
  templateUrl: './onlineDemarch-form.component.html',
})
export class OnlineDemarchFormComponent {
  @Input() currentStep: OnlineMediationSteps | StructuresListSteps;
  @Input() currentType: OnlineDemarche;
  @Input() form: UntypedFormGroup;
  @Input() filters: Filter[] = [];
  @Input() profile: User;
  @Output() validatePage = new EventEmitter<any>();

  public orientationUtils = new OrientationUtils();
  public pagesValidation: any[] = [];

  // Enums
  public HotlineMediationStepsEnum = HotlineMediationSteps;
  public onlineDemarchesCommonStepsEnum = OnlineDemarchesCommonSteps;
  public structuresListStepsEnum = StructuresListSteps;
  public onlineDemarcheTypeEnum = OnlineDemarche;
  public onlineDemarchesMeetingSteps = OnlineDemarchesMeetingSteps;
  public recapsType = RecapsType;

  public checkValidation(): void {
    switch (this.currentType) {
      case OnlineDemarche.onlineMediation:
        this.orientationUtils.setValidationsOnlineMediationForm(
          this.pagesValidation,
          this.form,
          (isValid) => this.validatePage.emit(isValid),
          this.currentStep as HotlineMediationSteps
        );
        break;
      case OnlineDemarche.structureList:
        this.orientationUtils.setValidationsStructuresForm(
          this.pagesValidation,
          this.form,
          (isValid) => this.validatePage.emit(isValid),
          this.currentStep as StructuresListSteps
        );
        break;
      case OnlineDemarche.common:
        this.orientationUtils.setValidationsOnlineDemarchesForm(
          this.pagesValidation,
          this.form,
          (isValid) => this.validatePage.emit(isValid),
          this.currentStep as OnlineDemarchesCommonSteps
        );
        break;
      case OnlineDemarche.meetings:
        this.orientationUtils.setValidationsOnlineMeetingForm(
          this.pagesValidation,
          this.form,
          (isValid) => this.validatePage.emit(isValid),
          this.currentStep as OnlineDemarchesMeetingSteps
        );
        break;
      default:
        throw new Error('Not implemented tunnel type in OnlineDemarchFormComponent');
    }
  }
}
